@@ -3,7 +3,7 @@ use anchor_lang::prelude::*;
 use anchor_spl::token;
 
 impl<'info> RedeemTokens<'info> {
-    /// Transfer tokens from source account to the redeemer's vault.
+    /// Burn IOU tokens from source account.
     pub fn burn_iou_tokens(&self, amount: u64) -> ProgramResult {
         let cpi_ctx = CpiContext::new(
             self.token_program.to_account_info(),
@@ -13,12 +13,11 @@ impl<'info> RedeemTokens<'info> {
                 authority: self.source_authority.to_account_info(),
             },
         );
-        token::burn(cpi_ctx, amount)?;
-        Ok(())
+        token::burn(cpi_ctx, amount)
     }
 
-    /// Transfer IOU tokens from the redemption vault to the user.
-    pub fn transfer_iou_tokens(&self, amount: u64) -> ProgramResult {
+    /// Transfer redemption tokens from the redemption vault to the user.
+    pub fn transfer_redemption_tokens(&self, amount: u64) -> ProgramResult {
         let seeds = gen_redeemer_signer_seeds!(self.redeemer);
         let signer_seeds = &[&seeds[..]];
         let cpi_ctx = CpiContext::new_with_signer(
